function [outa outb] = alks_model_ode()
   
    %Paramters and constants

    conv_mol = 1 / (6.02214179 * 10 ^ 2); %constant for converting molecules per cell to microM

    K_HC = 0.99/0.01*250*conv_mol; % equilibrium for AlkS + HC -> AlkS-HC
    K_S1 = sqrt((1-0.5)/0.5*(25*conv_mol)^2); %constant for Hill equation for binding to pAlkS1
    K_S2 = sqrt((1-0.99)/0.99*(0.01)^2); %constant for Hill equation for binding to pAlkS2
    K_B = sqrt((1-0.99)/0.99*(0.01)^2); %constant for Hill equation for binding to pAlkB

    mu = 0.1/3600; %growth rate in s^-1

    Np = 1; %copy number of the plasmids

    c_pAlkS1 = Np * conv_mol; % in microM
    c_pAlkS2 = Np * conv_mol; % in microM
    c_pAlkB = Np * conv_mol; % in microM

    mRNA_degradation = -1/300 * log(0.1); % 90% of the mRNA pool is degraded in 5 minutes
    AlkS_degradation = -1/3600 * log(0.1); % 90% of the AlkS pool is degraded in 1 h
    AlkB_degradation = -1/3600 * log(0.1); % dito

    beta_max_AlkS = (-1/3600 * log(0.1) + 0.1/3600) * 25/5; %solution for steady state
    beta_max_AlkB =(-1/3600 * log(0.1) + 0.1/3600) * 250/50; %solution for steady state
    
    beta_max_S1 = (-1/300 * log(0.1) + 0.1/3600) * 5/0.5; %solution for steady state
    beta_max_S2 = (-1/300 * log(0.1) + 0.1/3600) * 20/0.99; %solution for steady state
    beta_max_B = (-1/300 * log(0.1) + 0.1/3600) * 50/0.99; %solution for steady state

    sim_time = 300*60; %simulation is in seconds
    
    initials = [25 * conv_mol 0 5 * conv_mol 0]; %initial values for [AlkS], [AlkB], [mRNA_AlkS] and [mRNA_AlkB], if ss = 1 below, then these values do not matter much
    
    ss = 1; %make this value 1 if you want to start at steady state with an initial hydrocarbon concentration
    if ss == 1, [t,result] = ode23s(@ODE_solver,0:5e3:1e4,initials); initials = result(end,:); ss = 0; end %calculates the steady state
    
    [t,result] = ode23s(@ODE_solver,0:sim_time/500:sim_time,initials); %run the main ODE
    
    result2 = []; %reconstruct the activity from the promoters and the AlkS-HC binding from ODE data
    for i = 1:length(result)
        result2(i,:) = output(t(i), result(i,:));
    end
       
    function x = ODE_solver (t, w) % ode function
        
        AlkS_tot = w(1);
        AlkB = w(2);
        mRNA_AlkS = w(3);
        mRNA_AlkB = w(4);
        
        HC_tot = HC_calc(t,ss);
        
        temp = roots([1 -(AlkS_tot + HC_tot + K_HC) AlkS_tot*HC_tot]); %calculate how much AlkS and HC bind with each other
        temp = temp(temp>=0 & temp<=min([AlkS_tot HC_tot]));
        
%         AlkS_free = AlkS_tot - temp(1);
%         HC_free = HC_tot - temp(1);
        AlkS_HC = temp(1);
        
        f_pAlkS1 = 1 - (AlkS_tot^2/(K_S1^2 + AlkS_tot^2)); %calculate the activity of the promoters from Hill functions
        f_pAlkS2 = AlkS_HC^2/(K_S2^2 + AlkS_HC^2);
        f_pAlkB = AlkS_HC^2/(K_B^2 + AlkS_HC^2);
        
        %ODE for proteins from mass balances
        x(1) = (1 - crc_calc(t)) * beta_max_AlkS * mRNA_AlkS - (AlkS_degradation + mu) * AlkS_tot;
        x(2) = (1 - crc_calc(t)) * beta_max_AlkB * mRNA_AlkB - (AlkB_degradation + mu) * AlkB;
        %ODE for mRNA from mass balances
        x(3) = (1 - crp_calc(t)) * (beta_max_S1 * f_pAlkS1 * c_pAlkS1 + beta_max_S2 * f_pAlkS2 * c_pAlkS2) - (mRNA_degradation + mu) * mRNA_AlkS;
        x(4) = beta_max_B * f_pAlkB * c_pAlkB - (mRNA_degradation + mu) * mRNA_AlkB;
        
        x = x';
    end

    function outp = output(t,in) %function to reconstruct data from the ODE
        AlkS_tot = in(1);
%         AlkB = in(2);
%         mRNA_AlkS = in(3);
%         mRNA_AlkB = in(4);
        
        HC_tot = HC_calc(t,ss);
        
        temp = roots([1 -(AlkS_tot + HC_tot + K_HC) AlkS_tot*HC_tot]);
        temp = temp(temp>=0 & temp<=min([AlkS_tot HC_tot]));
        
%         AlkS_free = AlkS_tot - temp(1);
%         HC_free = HC_tot - temp(1);
        AlkS_HC = temp(1);
        
        f_pAlkS1 = 1 - (AlkS_tot^2/(K_S1^2 + AlkS_tot^2));
        f_pAlkS2 = AlkS_HC^2/(K_S2^2 + AlkS_HC^2);
        f_pAlkB = AlkS_HC^2/(K_B^2 + AlkS_HC^2);
        
        outp = [HC_tot AlkS_HC f_pAlkS1 f_pAlkS2 f_pAlkB];
        
    end

    function u = HC_calc(v,ss) %describes the input function, the hydrocarbon concentration
        if ss == 1, u = HC_calc(0,0); else
%             u = 1;
            u = 1 / (1 + exp(-1 * (v - 600))) - 1 / (1 + exp(-1 * (v - 180*60)));
        end
    end

    function u = crc_calc(v) %crc inhibition for the putida system
        u = 0;
%         u = 0.8 - 0.8 / (1 + exp(-1 * (v - 3600)));
    end
    
    function u = crp_calc(v) %crp inhibition for the pCaiF construct
        u = 0;
%         u = 0.8 - 0.8 / (1 + exp(-1 * (v - 3600)));
    end
    
    th = t ./ 60; %time in minutes for the x axes
    
    close all
    figure(1) %plot, plot, plot

    subplot(331)
    plot(th,result2(:,3))
    title('Fraction active pAlkS1')
    axis([0 sim_time / 60 0 1])
    xlabel('time (min)')
    ylabel('Fraction active pAlkS1')
    
    subplot(332)
    plot(th,result2(:,4))
    title('Fraction active pAlkS2')
    axis([0 sim_time / 60 0 1])
    xlabel('time (min)')
    ylabel('Fraction active pAlkS2')
    
    subplot(333)
    plot(th,result2(:,5))
    title('Fraction active pAlkB')
    axis([0 sim_time / 60 0 1])
    xlabel('time (min)')
    ylabel('Fraction active pAlkB')
 
    subplot(334)
    plot(th, result2(:,2));
    title('AlkS-HC level') %in microM
    axis([0 sim_time/60 0 1.05*max(result2(:,2))])
    xlabel('time (min)')
    ylabel('AlkS-HC concentration (microM)')
    
    subplot(335)
    plot(th,result(:,3))
    title('mRNA level of AlkS') %in microM
    axis([0 sim_time/60 0 1.05*max(result(:,3))])
    xlabel('time (min)')
    ylabel('AlkS mRNA concentration (microM)')
    
    subplot(336)
    plot(th,result(:,4))
    title('mRNA level of AlkB') %in microM
    axis([0 sim_time/60 0 1.05*max(result(:,4))])
    xlabel('time (min)')
    ylabel('AlkB mRNA concentration (microM)')
    
    subplot(337)
    plot(th,result2(:,1))
    title('total hydrocarbon')
    axis([0 sim_time/60 0 1.05*max(result2(:,1))])
    xlabel('time (min)')
    ylabel('total hydrocarbon concentration (microM)')
    
    subplot(338)
    plot(th, result(:,1))
    title('total AlkS')
    axis([0 sim_time/60 0 1.05*max(result(:,1))])
    xlabel('time (min)')
    ylabel('total AlkS concentration (microM)')
    
    subplot(339)
    outa = result(:,2);
    outb = t;
    plot(th,result(:,2))
    title('AlkB') %in microM
    axis([0 sim_time/60 0 1.05*max(result(:,2))])
    xlabel('time (min)')
    ylabel('AlkB concentration (microM)')
end